Welcome to the chinook package developed by Ryan Day at the University of British Columbia.

This package has been developed originally with the intention of simulating matrix-element effects in Angle-Resolved Photoemission Spectroscopy (ARPES) experiments.
This objective has however required a substantial amount of code infrastructure for generating and diagnosing tight-binding models, and consequently,
the functionality has been expanded (and will continue to do so) to allow for more broad exploration of these model Hamiltonians.

Here you will find all relevant modules and libraries for running calculations with this package.

For any questions which you do not find explanations in the documentation files, please do not hesitate to contact me at
rpday7_at_gmail_dot_com


Thanks!

Ryan Day
